@@ -54,7 +54,6 @@ class VideoVariable(Variable):
         ('default', _("Auto detection")),
         ('radeon', _("AMD Radeon (radeon)")),
         ('amdgpu', _("AMD AMDGPU (amdgpu)")),
-        ('fglrx', _("AMD Catalyst (fglrx)")),
         ('modesetting', _("Framebuffer device (modesetting)")),
         ('vesa', _("Generic VESA (vesa)")),
         ('intel', _("Intel (intel)")),
@@ -162,8 +161,7 @@ class VariableOsInstallX11VideoAvailable(VideoVariable):
     """
     type = "list"
     # supported = ["nvidia", "fglrx", "amdgpu", "nouveau", "intel", "radeon"]
-    supported = ["nvidia", "fglrx", "amdgpu",
-                 "modesetting",
+    supported = ["nvidia", "amdgpu","modesetting",
                  "nouveau", "intel", "radeon", "vesa"]
 
     def get(self):
