@@ -575,7 +575,8 @@ class VariableOsDiskFormat(ReadonlyVariable):
                 except BtrfsError:
                     pass
             return fs
-
+        b = [x for x in self.Get('os_disk_dev')]
+        a = [getFormat(x) for x in self.Get('os_disk_dev')]
         return [getFormat(x) for x in self.Get('os_disk_dev')]
 
 
@@ -1321,9 +1322,9 @@ class VariableOsLocationFormat(LocationHelper, Variable):
                     return "swap"
                 elif mount.startswith('/boot/efi'):
                     return "vfat"
-                if mount == "/":
-                    if root_format and root_format in allAvailFS:
-                        return root_format
+                # if mount == "/":
+                #     if root_format and root_format in allAvailFS:
+                #         return root_format
                 else:
                     if dev in diskFormat and diskFormat[dev] in allAvailFS:
                         if mount.count('/') == 1 or mount == "/var/calculate":
